#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################################
# casetta-gtk.py - Graphic data manager for casio calculators
# (c) 2006 Florian Birée aka Thesa <florian.biree@laposte.net> ~ http://filyb.info/
#
# Version 0.1.0
#
# changelog:
#
# # version 0.1.0:
#
#   o First release
#
############################################################################
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
# http://www.gnu.org/copyleft/gpl.html
#
############################################################################

__author__ = "Florian Birée"
__version__ = "0.1.0"
copyright = "Florian Birée, 2006, under GNU/GPL (http://www.gnu.org/copyleft/gpl.html)"

#i18n
APP = 'casetta-gtk'
#DIR = 'locale'

import gettext #,locale
gettext.install(APP)
#locale.setlocale(locale.LC_ALL, '')
#gettext.bindtextdomain(APP, DIR)
#gettext.textdomain(APP)


#Imports
import gtk, gtk.glade
import casetta
import os, sys

#Gui classes
class MakeGui:
    """ Main window class """

    def __init__( self, filename = '' ):
        """ Init the GUI, optionaly load filename """
        #gui & connexions
        self.gui = gtk.glade.XML( fname="casetta-gtk.glade", domain=APP )
        self.gui.get_widget( "wmain" ).connect( "delete_event", self.destroy )
        self.gui.get_widget( "editor" ).get_buffer().connect( "changed", self.on_editor_change )
        self.gui.signal_autoconnect( self )
        self.textInit()
        self.cp = gtk.Clipboard(display=gtk.gdk.display_get_default(), selection="CLIPBOARD")
        #init variables
        self.changed = 0
        self.filename = ''
        self.ed_currentId = -1
        self.ctx_id = -1
        self.loadtext = 0
        #Creat an empty file or open filename
        if filename == '' :
            self.fd = casetta.FileData()
        else :
            self.fd = casetta.fileOpen(filename)
            self.filename = filename
        self.refreshTitle()
        self.select(-1)
        #Fill data list and Equiv list
        self.buildDataList()
        self.refreshDataList()
        self.buildEquivList()
        #Check if /dev/casio exist
        checkPort()
        
    ################# Event manager
    def destroy( self, widget, data=None ):
        """ On window destroy: quit """
        self.closeFd()
        gtk.main_quit()
    
    def on_quitter1_activate( self, gui ):
        """ Quit (menu entry) """
        self.closeFd()
        gtk.main_quit()

    def on_a_propos1_activate( self, gui ):
        """ About (menu entry) """
        about=self.gui.get_widget( "aboutdialog" )
        about.connect( "delete_event", self.hidewindow )
        about.show()
        
    def hidewindow( self, w, event, data=None ):
        """ Hide a window """
        w.hide()
        return True
        
    def on_nouveau1_activate( self, gui ):
        """ New FileData (menu entry) """
        if self.closeFd() :
            self.fd = casetta.FileData()
            self.changed = 0
            self.filename = ''
            self.refreshDataList()
            self.refreshTitle()
            self.select(-1)
    def on_toolNew_clicked(self, gui):
        """ New FileData (toolbar entry) """
        self.on_nouveau1_activate(None)
    
    def on_ouvrir1_activate(self, gui):
        """ Open a file - and making a new fileData (menu entry) """
        if self.closeFd() :
            fs = openFile([(_('Newcat files'),'*.newcat'),(_('cafix datas'),'*.cafix'),(_('Cat files'),'*.[cC][aA][tT]'),(_('Fxi files'),'*.[fF][xX][iI]'),(_('All files'),'*')])
            if fs != '' :
                #Load fs
                self.fd = casetta.fileOpen(fs)
                self.changed = 0
                self.filename = fs
                self.refreshDataList()
                self.refreshTitle()
                self.select(-1)
    def on_toolOpen_clicked(self, gui):
        """ Open a file (toolbar button) """
        self.on_ouvrir1_activate(None)
    
    def on_enregistrer1_activate(self, gui):
        """ Save a file (menu entry) """
        if self.filename == '' :
            #Save as
            self.on_enregistrer_sous1_activate(None)
        else :
            self.fd.save(self.filename)
            self.fd.changed = 0
            self.refreshTitle()
    def on_toolSave_clicked(self, gui):
        """ Save a file (toolbar button) """
        self.on_enregistrer1_activate(None)
        
    def on_enregistrer_sous1_activate(self, gui):
        """ Save as (menu entry) """
        fs = saveFile([(_('Newcat files'),'*.newcat'),(_('cafix datas'),'*.cafix'),(_('Cat files'),'*.[cC][aA][tT]'),(_('Fxi files'),'*.[fF][xX][iI]'),(_('All files'),'*')])
        if fs != '' :
            self.filename = fs
            self.fd.save(self.filename)
            self.changed = 0
            self.refreshTitle()
        
    def on_importer1_activate(self, gui):
        """ Import a file (menu entry) """
        fs = openFile([(_('Newcat files'),'*.newcat'),(_('cafix datas'),'*.cafix'),(_('Cat files'),'*.[cC][aA][tT]'),(_('Fxi files'),'*.[fF][xX][iI]'),(_('All files'),'*')])
        if fs != '' :
            l = self.fd.add(fs)
            for did in l :
                nn = self.checkName(did)
                if nn == '' :
                    #del the data
                    self.fd.delData(did)
                else :
                    self.fd.data[did].name = nn
            self.refreshDataList()
            self.changed = 1
            self.refreshTitle()
        
    def on_dataList_click(self, treeview, event):
        """ On click on the data list """
        x = int(event.x)
        y = int(event.y)
        pthinfo = treeview.get_path_at_pos(x, y)
        if pthinfo == None:return
        path, col, cellx, celly = pthinfo
        treeview.grab_focus()
        treeview.set_cursor( path, col, 0)
        model = treeview.get_model()
        iter = model.get_iter(path)
        content = model[iter]
        #content[0] -> checkbox
        #content[1] -> nom
        #Find the dataID
        try :
            did = [data.name for data in self.fd.data].index(content[1])
        except :
            did = -1
        self.ctx_id = did
        #Select the data
        self.select(did)
        if event.button == 3:
            #context menu
            if did == -1 :
                self.gui.get_widget( "renommer1" ).hide()
                self.gui.get_widget( "supprimer2" ).hide()
                self.gui.get_widget( "separateur1" ).hide()
            elif self.fd.data[did].dType == casetta.program :
                self.gui.get_widget( "renommer1" ).show()
                self.gui.get_widget( "supprimer2" ).show()
                self.gui.get_widget( "separateur1" ).show()
            else :
                self.gui.get_widget( "renommer1" ).hide()
                self.gui.get_widget( "supprimer2" ).show()
                self.gui.get_widget( "separateur1" ).show()
            time = event.time
            self.gui.get_widget( "menu").popup( None, None, None, event.button, time)
                
            
    def on_editor_change(self, gui):
        """ When a change occur on the editor """
        if self.ed_currentId != -1 and not self.loadtext :
            self.changed = 1
            self.refreshTitle()
            ebuffer = self.textview.get_buffer()
            #Synchronize with data
            self.fd.data[self.ed_currentId].setText(ebuffer.get_text(ebuffer.get_start_iter(), ebuffer.get_end_iter()))
            #Refresh syntax coloration
            ##**For a next version**##
            
    def on_equivList_button_press_event(self, treeview, event):
        """ On click in the Equiv list """
        x = int(event.x)
        y = int(event.y)
        pthinfo = treeview.get_path_at_pos(x, y)
        if pthinfo != None:
            path, col, cellx, celly = pthinfo
            treeview.grab_focus()
            treeview.set_cursor( path, col, 0)
        model = treeview.get_model()
        iter = model.get_iter(path)
        content = model[iter]
        #content[0] -> equiv to insert
        ebuffer = self.textview.get_buffer()
        ebuffer.insert_at_cursor(content[0])

    def on_nouveau_programme1_activate(self, gui):
        """ New program (context menu) """
        nom = input_box(title=_("New program"), message=_("Name of the new program (8 letters maximum):"))
        if nom == '' :
            return
        elif len(nom) > 8 :
            nom = nom[:8]
        did = self.fd.newData()
        self.fd.data[did].name = nom
        self.fd.data[did].dType = casetta.program
        nn = self.checkName(did)
        if nn == '' :
            #del the data
            self.fd.delData(did)
            return
        else :
            self.fd.data[did].name = nn
        self.refreshDataList()
        self.changed = 1
        self.refreshTitle()

    def on_renommer1_activate(self, gui):
        """ Rename a data (context menu entry) """
        if not self.ctx_id + 1 : return
        if self.fd.data[self.ctx_id].dType == casetta.program :
            on = self.fd.data[self.ctx_id].name
            nn = input_box(title=_("Rename a program"), message=_("New name of the program (8 letters maximum):"),default_text=on)
            self.fd.data[self.ctx_id].name = nn
            nn = self.checkName(self.ctx_id)
            if nn == '' :
                #cancel the renaming
                self.fd.data[self.ctx_id].name = on
                return
            else :
                self.fd.data[self.ctx_id].name = nn
            self.refreshDataList()
            self.changed = 1
            self.refreshTitle()

    def on_supprimer2_activate(self, gui):
        """ Delete a data (context menu entry) """
        if not self.ctx_id + 1 : return
        if ynMsg(_('Do you really want to delete the data "%s"?') % self.fd.data[self.ctx_id].name) :
            self.fd.delData(self.ctx_id)
            self.refreshDataList()
            self.changed = 1
            self.refreshTitle()

    def on_couper1_activate(self, gui):
        """ Cut in the program editor (menu entry) """
        if not self.ed_currentId + 1: return
        ebuffer = self.textview.get_buffer()
        ebuffer.cut_clipboard(self.cp,self.textview.get_editable())
        
    def on_copier1_activate(self, gui):
        """ Copy in the program editor (menu entry) """
        if not self.ed_currentId + 1: return
        ebuffer = self.textview.get_buffer()
        ebuffer.copy_clipboard(self.cp)
        
    def on_coller1_activate(self, gui):
        """ Paste in the program editor (menu entry) """
        if not self.ed_currentId + 1: return
        ebuffer = self.textview.get_buffer()
        ebuffer.paste_clipboard(self.cp, None,self.textview.get_editable() )
        
    def on_supprimer1_activate(self, gui):
        """ Delete in the program editor (menu entry) """
        if not self.ed_currentId + 1: return
        ebuffer = self.textview.get_buffer()
        ebuffer.delete_selection(True, self.textview.get_editable())
        
    def on_configurer_le_port1_activate(self, gui):
        """ Configure the calculator port (menu entry)"""
        if infoMsg(_("When the setup tool will be running, use up and down arrows to choose the COM port. Hit the 'q' key to close the tool.")):
            portConfigure()
            
    def on_toggled(self,gui, path, user_data):
        """ On click on list data checkbox """
        if not self.ctx_id +1 : return
        model, column = user_data
        model[path][column] = not model[path][column]
        if model[path][column] :
            #Check if self.ctx_id is in self.fd.export
            if not self.ctx_id in self.fd.export :
                self.fd.export.append(self.ctx_id)
        else:
            #Check if self.ctx_id is NOT in self.fd.export
            if self.ctx_id in self.fd.export :
                self.fd.export.remove(self.ctx_id)
                
    def on_recevoir_des_donnees1_activate(self, gui):
        """ Receive data from a casio calculator (menu entry) """
        self.fromCasio()
    def on_toolReceive_clicked(self, gui):
        """ Receive data from a casio calculator (toolbar entry) """
        self.fromCasio()

    def on_envoyer_des_donnees1_activate(self, gui):
        """ Send data to a casio calculator (menu entry) """
        self.toCasio()
    def on_toolSend_clicked(self, gui):
        """ Send data to a casio calculator (toolbar entry) """
        self.toCasio()

    #####################  Others UI management functions
    def buildEquivList(self):
        """ Make the Equiv List """
        self.equivList = self.gui.get_widget( "equivList" )
        self.equivTS = gtk.TreeStore(str)
        
        self.equivList.set_model(self.equivTS)
        self.equivTvC = gtk.TreeViewColumn('equivalences')
        self.equivList.append_column(self.equivTvC)
        self.equivCell = gtk.CellRendererText()
        self.equivTvC.pack_start(self.equivCell,True)
        self.equivTvC.add_attribute(self.equivCell, 'text', 0)
        
        #Fill the Equiv list
        import catdic
        l = []
        for key in catdic.r2c:
            l.append(catdic.r2c[key])
        for key in catdic.or2c:
            l.append(catdic.or2c[key])
        for key in catdic.r2n:
            l.append(catdic.r2n[key])
        for key in catdic.or2n:
            l.append(catdic.or2n[key])
        for key in catdic.r2cl:
            l.append(catdic.r2cl[key])
        l.append('\\aster')
        l.append('\\slash')
        l.sort()
        for e in l:
            self.equivTS.append(None,[e])
        
    def buildDataList(self):
        """ Make the Data List """
        self.dataList = self.gui.get_widget( "dataList" )
        self.dataTreeStore = gtk.TreeStore(int,str)
        
        self.dataList.set_model(self.dataTreeStore)
        # add checkbox column
        self.dataCCb = gtk.TreeViewColumn()
        self.dataCCb.set_resizable(False)
        self.dataList.append_column(self.dataCCb)
        # add the toggle renderer
        check = gtk.CellRendererToggle()
        self.dataCCb.pack_start(check, expand = False)
        self.dataCCb.add_attribute(check, "active", 0)
        check.connect("toggled",self.on_toggled,(self.dataTreeStore,0))
        self.dataCCb.set_visible(True)
        # add data column
        self.dataTvColumn = gtk.TreeViewColumn('Data')
        self.dataTvColumn.set_resizable(False)
        self.dataList.append_column(self.dataTvColumn)
        # add the text renderer
        dataCell = gtk.CellRendererText()
        self.dataTvColumn.pack_start(dataCell,True)
        self.dataTvColumn.add_attribute(dataCell, 'text', 1)
        self.dataTvColumn.set_visible(True)
        
    def refreshDataList(self):
        """ Fill/refresh the Data List """
        self.dataTreeStore.clear()                      #clear the list
        self.prgmItem = self.dataTreeStore.append(None,[False,_('Programs')])
        self.unknownItem = self.dataTreeStore.append(None,[False,_('Unknowns')])
        self.bakItem = self.dataTreeStore.append(None,[False,_('Backups')])
        #Fill childrens items
        self.dataItems = {}
        for index in range(len(self.fd.data)) :
            if index in self.fd.export: ex = True
            else: ex = False
            if self.fd.data[index].dType == casetta.program :
                self.dataItems[index] = self.dataTreeStore.append(self.prgmItem,[ex,self.fd.data[index].name])
            elif self.fd.data[index].dType == casetta.unknown :
                print 'List::unknown found. Index:',index
                self.dataItems[index] = self.dataTreeStore.append(self.unknownItem,[ex,self.fd.data[index].name])
                
    def refreshTitle(self):
        """ Refresh window title """
        w = self.gui.get_widget( "wmain" )
        if self.filename == '' :
            fichier = _('No name')
        else :
            fichier = os.path.basename(self.filename)
        if self.changed :
            mod = '* '
        else :
            mod = ''
        w.set_title('%s %s- Casetta-gtk'% (fichier,mod))
        
    def select(self, did):
        """ Change the windows follow the selected data """
        textFrame = self.gui.get_widget( "scrolledwindow3" )
        labelFrame = self.gui.get_widget( "info" )
        equivFrame = self.gui.get_widget( "scrolledwindow2" )
        #If nothing is selected (did=-1)
        if did == -1 :
            textFrame.hide()
            labelFrame.show()
            equivFrame.hide()
            labelFrame.set_text(_("Select data in the left list to edit it or obtain informations on it.\nYou can use the contextual menu (right click) to creat new data."))
            self.ed_currentId = -1
        else :
            if self.fd.data[did].dType == casetta.program :
                #programs :
                textFrame.show()
                labelFrame.hide()
                equivFrame.show()
                #load the program in the editor
                self.openProgram(did)
            else :
                #others data
                textFrame.hide()
                labelFrame.show()
                equivFrame.hide()
                labelFrame.set_text(_("Unknown data type\nName: %s\nSize: %s") % (self.fd.data[did].name, str(len(self.fd.data[did].rawData))))
                self.ed_currentId = -1
                
    def textInit(self):
        """ Init the text editor """
        self.textview = self.gui.get_widget( "editor" )
        self.textview.set_wrap_mode(gtk.WRAP_NONE)
    
    def colorAll(self):
        """ Color all text in the editor """
        ##**For a next version**##
        pass
        
    def colorLine(self,line):
        """ Color a specific line """
        ##**For a next version**##
        pass
                
    ############################# Others functions
    def closeFd(self):
        """ Close current FileData (and ask to save it) """
        if self.changed :
            if ynMsg(_('Do you want to save this file?')) :
                #yes
                self.on_enregistrer1_activate(None)
            else:
                #no
                return 1
        else:
            return 1
        #return 0 : don't close
        
    def openProgram(self, did):
        """ Open a program in the editor """
        ebuffer = self.textview.get_buffer()
        self.ed_currentId = did
        self.loadtext = 1
        ebuffer.set_text(self.fd.data[did].getText())
        self.loadtext = 0
        #Syntax coloration for all the text
        ##**For a next version**##
        
    def checkName(self, did):
        """ Check the did data haven't an already used name.
        If it's the case, ask another name.
        Return the data name, or nothing if the user don't want to change it. """
        nn = self.fd.data[did].name
        while 1 :
            if [d.name for d in self.fd.data].count(nn) > 1 or len(nn) > 8:
                nn = input_box(title=_("Rename data"), message=_("The name you choose is already used or not valid. Please choose another (8 letters maximum):"), default_text=nn)
                if nn == '' :
                    return ''
            else :
                return nn
    
    def fromCasio(self):
        """ import data from a casio calculator """
        #check cafix
        if not checkCafix(): return
        #Check /dev/casio
        if not checkPort() : return
        #Choice a temp directory and make it
        folder = os.tmpnam() + '-casetta'
        os.mkdir(folder)
        #Get the current dir
        curdir = os.path.abspath(os.path.curdir)
        #Make the shell script to run to receive data in folder/receive.sh
        f = open(os.path.join(folder,'receive.sh'),'w')
        ctn = "#!/bin/sh\n"
        ctn += "#Receive script made by casetta-gtk\n"
        ctn += "cd %s\n" % folder
        ctn += "echo %s\n" % _('You can now send data from the calculator')
        ctn += "cafix -r\n"
        f.write(ctn)
        f.close()
        #Run folder/receive.sh in a console (gnome-terminal -e)
        os.system("gnome-terminal -e 'sh %s'" % os.path.join(folder,'receive.sh'))
        #import all cafix files
        l = self.fd.addData(casetta.casioImport(folder))
        for did in l :
            nn = self.checkName(did)
            if nn == '' :
                #del the data
                self.fd.delData(did)
            else :
                self.fd.data[did].name = nn
            self.refreshDataList()
            self.changed = 1
            self.refreshTitle()
            
    def toCasio(self):
        """ Send selected data to the casio calculator """
        #Check cafix
        if not checkCafix():return
        #Check /dev/casio
        if not checkPort():return
        #Check if export isn't empty
        if self.fd.export == []:
            errMsg(_("You haven't choice data to send to your calculator. Select first data by using the checkboxes in the list to the left. Next retry to send data."))
            return
        #Print the message
        if not infoMsg(_("Run your calculator, and set it in the state 'Receiving'.")):
            return
        #Choice a temp directory and make it
        script = os.tmpnam() + '.sh'
        folder = os.tmpnam() + '-casetta'
        os.mkdir(folder)
        #Export data in this folder
        casetta.casioExport(folder,self.fd)
        #Make the shell script to run to send data in script
        f = open(script,'w')
        ctn = "#!/bin/sh\n"
        ctn += "#Send script made by casetta-gtk\n"
        ctn += "cd %s\n" % folder
        ctn += "cafix -s *\n"
        f.write(ctn)
        f.close()
        #Run script in a console (gnome-terminal -e)
        os.system("gnome-terminal -e 'sh %s'" % script)

class EntryDialog( gtk.Dialog):
    """ Input dialog class """
    
    def __init__(self, message="", default_text='', modal= True):
        gtk.Dialog.__init__(self)
        #self.connect("destroy", self.quit)
        #self.connect("delete_event", self.quit)
        if modal:
            self.set_modal(True)
        box = gtk.VBox(spacing=10)
        box.set_border_width(10)
        self.vbox.pack_start(box)
        box.show()
        if message:
            label = gtk.Label(message)
            box.pack_start(label)
            label.show()
        self.entry = gtk.Entry()
        self.entry.set_text(default_text)
        box.pack_start(self.entry)
        self.entry.show()
        self.entry.grab_focus()
        button = gtk.Button(_("OK"))
        button.connect("clicked", self.click)
        button.set_flags(gtk.CAN_DEFAULT)
        self.action_area.pack_start(button)
        button.show()
        button.grab_default()
        button = gtk.Button(_("Cancel"))
        button.connect("clicked", self.quit)
        button.set_flags(gtk.CAN_DEFAULT)
        self.action_area.pack_start(button)
        button.show()
        self.ret = None
    def quit(self, w=None, event=None):
        self.hide()
        self.ret = ''
        self.response(0)
    def click(self, button):
        self.hide()
        self.ret = self.entry.get_text()
        self.response(1)

#Many functions:

def input_box(title="Input Box", message="", default_text='', modal= True):
    """ Open an input box and return the result """
    win = EntryDialog(message, default_text, modal=modal)
    win.set_title(title)
    win.run()
    return win.ret

def ynMsg(message):
    """ Show a Yes/No (Question) message, and return True if Yes, False if No """
    r = 0
    d = gtk.MessageDialog(None,gtk.DIALOG_MODAL,gtk.MESSAGE_QUESTION,gtk.BUTTONS_YES_NO,message)
    if d.run() == gtk.RESPONSE_YES :
        r = 1
    d.destroy()
    return r

def infoMsg(message):
    """ Info (OK/Cancel) message, return True if Ok, False if Cancel """
    r = 0
    d = gtk.MessageDialog(None,gtk.DIALOG_MODAL,gtk.MESSAGE_INFO,gtk.BUTTONS_OK_CANCEL,message)
    if d.run() == gtk.RESPONSE_OK :
        r = 1
    d.destroy()
    return r

def errMsg(message):
    """ Show an error message """
    d = gtk.MessageDialog(None,gtk.DIALOG_MODAL,gtk.MESSAGE_WARNING,gtk.BUTTONS_OK,message)
    d.run()
    d.destroy()
    return

def openFile(patternList = []):
    """ Show a dialog to open a file, return the filename or nothing if cancel """
    dialog_window = gtk.FileChooserDialog(None, None, gtk.FILE_CHOOSER_ACTION_OPEN , (_('Cancel'),0,_('OK'),1) )
    for pattern in patternList :
        ffilter = gtk.FileFilter()
        ffilter.set_name(pattern[0])
        ffilter.add_pattern(pattern[1])
        dialog_window.add_filter(ffilter)
    
    reponse = dialog_window.run() 
    fichier = dialog_window.get_filename()
    dialog_window.destroy()
    
    if reponse :
        return fichier
    else :
        return

def saveFile(patternList = []):
    """ Show a dialog to save a file. Return the filemane or nothing if cancel.
    Ask if the file already exist """
    dialog_window = gtk.FileChooserDialog(None, None, gtk.FILE_CHOOSER_ACTION_SAVE , (_('Cancel'),0,_('OK'),1) )
    for pattern in patternList :
        ffilter = gtk.FileFilter()
        ffilter.set_name(pattern[0])
        ffilter.add_pattern(pattern[1])
        dialog_window.add_filter(ffilter)
    
    reponse = dialog_window.run() 
    fichier = dialog_window.get_filename()
    
    #Check if the file alreday exist
    if not os.path.exists(fichier) or ynMsg(_("This file already exist. Replace it?")) :
        dialog_window.destroy()
        if reponse :
            return fichier
        else :
            return
            
def portConfigure() :
    """ Configure /dev/casio using cafix-setup """
    #KDE Command: kdesu 'konsole -e cafix-setup'
    #Gnome Command: gksu 'gnome-terminal -e cafix-setup'
    com = "gksu 'gnome-terminal -e cafix-setup'"
    os.system(com)
    return os.path.exists('/dev/casio')
    
def checkPort() :
    """ Check if /dev/casio exist. If not, ask to run cafix-setup in root
    Return True if /dev/casio is Ok, False else. """
    if not os.path.exists('/dev/casio') :
        if ynMsg(_("Your calculator port seem to be unconfigured. Do you want to run the setup tool?\nWhen the setup tool will be running, use up and down arrows to choose the COM port. Hit the 'q' key to close the tool.")):
            return portConfigure()
        else :
            return False
    else :
        return True
        
def checkCafix() :
    """ Check if cafix is in the path """
    if len([path for path in os.defpath.split(os.pathsep) if os.path.exists(os.path.join(path,'cafix'))]) == 0 :
        errMsg(_("The command cafix was not found in your path.\nYou must install cafix using your package manager or at http://cafix.sourceforge.net/ to import data from/export data to your casio calculator."))
        return 0
    else :
        return 1

#Main code
if __name__ == "__main__":
    if len(sys.argv) == 1 :
        filename = ''
    elif sys.argv[1].lower() == '-h' or sys.argv[1].lower() == '--help' :
        #CLI help text
        print 'Casetta-gtk -- Graphic interface for casetta'
        print 'Usage: casetta-gtk filename'
        print 'Open filename in Casetta-gtk'
        print "You can also use 'casetta-gtk --help' to display this message"
        sys.exit()
    else :
        #check if sys.argv[1] is really a file
        if os.path.isfile(sys.argv[1]) :
            filename = sys.argv[1]
        else :
            print 'Bad filename. Run casetta-gtk normally'
            filename = ''
    ui = MakeGui(filename)
    gtk.main()
